aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJean-Michel Vedrine <vedrine@vedrine.org>2019-04-28 09:54:37 +0200
committerJean-Michel Vedrine <vedrine@vedrine.org>2019-04-28 09:54:37 +0200
commitf83f95e9c7d1953b7e760feea862e45304cd9443 (patch)
tree4d065bf22881900010650fa63b46729f3a1c9819
parente0dda838a0cffd6b1f4fd3706e75537c1906b5ec (diff)
New version of mobile support
-rw-r--r--classes/output/mobile.php35
-rw-r--r--db/mobile.php50
-rw-r--r--javascript/mobile.js68
-rw-r--r--mobile/addon-qtype-algebra.html9
-rw-r--r--mobile/mobile.js76
-rw-r--r--mobile/styles_app.css4
6 files changed, 227 insertions, 15 deletions
diff --git a/db/mobile.php b/db/mobile.php
new file mode 100644
index 0000000..3ce7338
--- /dev/null
+++ b/db/mobile.php
@@ -0,0 +1,50 @@
+<?php
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
+
+/**
+ * algebra question type capability definition
+ *
+ * @package qtype_algebra
+ * @copyright 2019 Jean-Michel Vedrine
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ */
+defined('MOODLE_INTERNAL') || die();
+
+$addons = [
+ "qtype_algebra" => [
+ "handlers" => [ // Different places where the add-on will display content.
+ 'algebra' => [ // Handler unique name (can be anything).
+ 'displaydata' => [
+ 'title' => 'algebra question',
+ 'icon' => '/question/type/algebra/pix/icon.gif',
+ 'class' => '',
+ ],
+ 'delegate' => 'CoreQuestionDelegate', // Delegate (where to display the link to the add-on).
+ 'method' => 'mobile_get_algebra',
+ 'offlinefunctions' => [
+ 'mobile_get_algebra' => [],// function in classes/output/mobile.php
+ ], // Function needs caching for offline.
+ 'styles' => [
+ 'url' => '/question/type/algebra/mobile/styles_app.css',
+ 'version' => '1.00'
+ ]
+ ]
+ ],
+ 'lang' => [
+ ['pluginname', 'qtype_algebra'], // matching value in lang/en/qtype_algebra
+ ],
+ ]
+];
diff --git a/javascript/mobile.js b/javascript/mobile.js
new file mode 100644
index 0000000..3fb9542
--- /dev/null
+++ b/javascript/mobile.js
@@ -0,0 +1,68 @@
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
+
+/**
+ * support for the mdl35+ mobile app
+ * This file is the equivalent of
+ * qtype/algebra/classes/algebra.ts in the core app
+ * e.g.
+ * https://github.com/moodlehq/moodlemobile2/blob/v3.5.0/src/addon/qtype/ddwtos/classes/ddwtos.ts
+ */
+
+
+var that = this;
+var result = {
+
+ componentInit: function() {
+ if (!this.question) {
+ console.warn('Aborting because of no question received.');
+ return that.CoreQuestionHelperProvider.showComponentError(that.onAbort);
+ }
+ const div = document.createElement('div');
+ div.innerHTML = this.question.html;
+ // Get question questiontext.
+ const questiontext = div.querySelector('.qtext');
+
+ // Replace Moodle's correct/incorrect and feedback classes with our own.
+ this.CoreQuestionHelperProvider.replaceCorrectnessClasses(div);
+ this.CoreQuestionHelperProvider.replaceFeedbackClasses(div);
+
+ // Treat the correct/incorrect icons.
+ this.CoreQuestionHelperProvider.treatCorrectnessIcons(div);
+
+
+ if (div.querySelector('.readonly') !== null) {
+ this.question.readonly = true;
+ }
+ if (div.querySelector('.feedback') !== null) {
+ this.question.feedback = div.querySelector('.feedback');
+ this.question.feedbackHTML = true;
+ }
+
+ this.question.text = this.CoreDomUtilsProvider.getContentsOfElement(div, '.qtext');
+
+ if (typeof this.question.text == 'undefined') {
+ this.logger.warn('Aborting because of an error parsing question.', this.question.name);
+ return this.CoreQuestionHelperProvider.showComponentError(this.onAbort);
+ }
+
+ // Wait for the DOM to be rendered.
+ setTimeout(() => {
+
+ });
+ return true;
+ }
+};
+result;
diff --git a/mobile/addon-qtype-algebra.html b/mobile/addon-qtype-algebra.html
new file mode 100644
index 0000000..326026d
--- /dev/null
+++ b/mobile/addon-qtype-algebra.html
@@ -0,0 +1,9 @@
+<section ion-list *ngIf="question.text || question.text === ''">
+ <ion-item text-wrap>
+ <p><core-format-text [component]="component" [componentId]="componentId" [text]="question.text"></core-format-text></p>
+ </ion-item>
+ <ion-input padding-left type="text" placeholder="{{ 'core.question.answer' | translate }}"
+ [attr.name]="question.input.name" [value]="question.input.value" autocorrect="off"
+ [disabled]="question.input.readOnly" [ngClass]="[question.input.correctClass]">
+ </ion-input>
+</section>
diff --git a/mobile/mobile.js b/mobile/mobile.js
new file mode 100644
index 0000000..3b7a3ca
--- /dev/null
+++ b/mobile/mobile.js
@@ -0,0 +1,76 @@
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
+
+/**
+ * support for the mdl35+ mobile app. PHP calls this from within
+ * classes/output/mobile.php
+ * This file is the equivalent of
+ * qtype/algebra/classes/algebra.ts in the core app
+ * e.g.
+ * https://github.com/moodlehq/moodlemobile2/blob/v3.5.0/src/addon/qtype/ddwtos/classes/ddwtos.ts
+ */
+
+
+var that = this;
+var result = {
+
+ componentInit: function() {
+ if (!this.question) {
+ console.warn('Aborting because of no question received.');
+ return that.CoreQuestionHelperProvider.showComponentError(that.onAbort);
+ }
+ const div = document.createElement('div');
+ div.innerHTML = this.question.html;
+ // Get question questiontext.
+ const questiontext = div.querySelector('.qtext');
+
+ // Replace Moodle's correct/incorrect and feedback classes with our own.
+ // Only do this if you want to use the standard classes
+ this.CoreQuestionHelperProvider.replaceCorrectnessClasses(div);
+ this.CoreQuestionHelperProvider.replaceFeedbackClasses(div);
+
+ // Treat the correct/incorrect icons.
+ this.CoreQuestionHelperProvider.treatCorrectnessIcons(div);
+
+
+ if (div.querySelector('.readonly') !== null) {
+ this.question.readonly = true;
+ }
+ if (div.querySelector('.feedback') !== null) {
+ this.question.feedback = div.querySelector('.feedback');
+ this.question.feedbackHTML = true;
+ }
+
+ this.question.text = this.CoreDomUtilsProvider.getContentsOfElement(div, '.qtext');
+
+ if (typeof this.question.text == 'undefined') {
+ this.logger.warn('Aborting because of an error parsing question.', this.question.name);
+ return this.CoreQuestionHelperProvider.showComponentError(this.onAbort);
+ }
+
+ // Called by the reference in *.html to
+ // (afterRender)="questionRendered()
+ this.questionRendered = function questionRendered() {
+ //do stuff that needs the question rendered before it can run.
+ }
+
+ // Wait for the DOM to be rendered.
+ setTimeout(() => {
+ //put stuff here that will be pulled from the rendered question
+ });
+ return true;
+ }
+};
+result;
diff --git a/mobile/styles_app.css b/mobile/styles_app.css
new file mode 100644
index 0000000..f15562d
--- /dev/null
+++ b/mobile/styles_app.css
@@ -0,0 +1,4 @@
+
+.qtype-algebra .yourclassname {
+
+}
diff --git a/classes/output/mobile.php b/classes/output/mobile.php
index 86c6bd3..c2b11de 100644
--- a/classes/output/mobile.php
+++ b/classes/output/mobile.php
@@ -15,11 +15,11 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
* Mobile output class for algebra question type.
*
- * @package qtype_algebra
- * @copyright 2019 Jean-Michel Vedrine
- * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package qtype_algebra
+ * @copyright 2019 Jean-Michel Vedrine
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
namespace qtype_algebra\output;
@@ -27,24 +27,29 @@ namespace qtype_algebra\output;
defined('MOODLE_INTERNAL') || die();
/**
* Mobile output class for question type algebra.
* @copyright 2019 Jean-Michel Vedrine
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
class mobile {
+
/**
- * Returns the algebra question view for the mobile app.
+ * Returns the algebra question type for the quiz the mobile app.
*
* @return void
*/
- public static function algebra_view() {
+ public static function mobile_get_algebra() {
global $CFG;
return [
- 'templates' => [[
- 'id' => 'main',
- 'html' => file_get_contents($CFG->dirroot . '/question/type/algebra/mobile/algebra.html')
- ]],
- 'javascript' => file_get_contents($CFG->dirroot . '/question/type/algebra/mobile/algebra.js')
+ 'templates' => [
+ [
+ 'id' => 'main',
+ 'html' => file_get_contents($CFG->dirroot .'/question/type/algebra/mobile/qtype-algebra.html')
+ ]
+ ],
+ 'javascript' => file_get_contents($CFG->dirroot . '/question/type/algebra/mobile/mobile.js')
];
}
-} \ No newline at end of file
+}
@@ -15,11 +15,11 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
- * Mobile output class for algebra question type.
+ * Mobile output class for qtype_algebra
*
@@ -27,24 +27,29 @@ namespace qtype_algebra\output;
defined('MOODLE_INTERNAL') || die();
/**
- * Mobile output class for question type algebra.
- * @copyright 2019 Jean-Michel Vedrine
- * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * Mobile output class for algebra question type
+ *
+ * @package qtype_algebra
+ * @copyright 2019 Jean-Michel vedrine
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
class mobile {